import logging
import os
import shutil
import unittest

import peek_platform

peek_platform.PeekPlatformConfig.componentName = "unit_test"

from peek_agent_service.PeekAgentConfig import PeekAgentConfig

logging.basicConfig(level=logging.DEBUG)

logger = logging.getLogger(__name__)


class PeekAgentConfigTest(unittest.TestCase):
    COMPONENT_NAME = "unit_test"
    HOME_DIR = os.path.expanduser("~/%s.home" % COMPONENT_NAME)
    CONFIG_FILE_PATH = os.path.join(HOME_DIR, "config.json")

    def _rmHome(self):
        if os.path.exists(self.HOME_DIR):
            shutil.rmtree(self.HOME_DIR)

    def setUp(self):
        PeekAgentConfig._PeekFileConfigBase__instance = None
        self._rmHome()
        os.makedirs(self.HOME_DIR, PeekAgentConfig.DEFAULT_DIR_CHMOD)

        with open(self.CONFIG_FILE_PATH, "w") as fobj:
            fobj.write('{"nothing":{"is_true":true}}')

    def tearDown(self):
        self._rmHome()

    def testPlatformDetails(self):
        bas = PeekAgentConfig()

        # Defaults
        logger.info("platformVersion = %s", bas.platformVersion)
        bas.platformVersion = "4.4.4"

        PeekAgentConfig._PeekFileConfigBase__instance = None

        logger.info("platformVersion = %s", bas.platformVersion)
        self.assertEqual(bas.platformVersion, "4.4.4")



from os import path

from peek_plugin_base.PlatformDependencyTest import PlatformDependencyTestCaseBase


class PlatformDependencyTestCase(PlatformDependencyTestCaseBase):
    def setUp(self):
        self._pkgPath = path.dirname(__file__)

    def test_for_plugin_references_1(self):
        self._runCmd(self._checkForHyphensCmd % self._pkgPath)

    def test_for_plugin_references_2(self):
        self._runCmd(self._checkForUnderscoresCmd % self._pkgPath)



import logging

import win32service
import win32serviceutil
from twisted.internet import reactor

import peek_agent_service
from peek_platform.sw_install.PeekSwInstallManagerABC import IS_WIN_SVC

logger = logging.getLogger(__name__)


class PeekSvc(win32serviceutil.ServiceFramework):
    _svc_name_ = "peek-agent-service"
    _svc_display_name_ = "Peek Agent " + peek_agent_service.__version__
    _exe_args_ = IS_WIN_SVC
    _svc_deps_ = ["RpcSs"]

    def __init__(self, args):
        win32serviceutil.ServiceFramework.__init__(self, args)

        reactor.addSystemEventTrigger("after", "shutdown", self._notifyOfStop)

    def _notifyOfStop(self):
        self.ReportServiceStatus(win32service.SERVICE_STOPPED)

    def _notifyOfStart(self):
        self.ReportServiceStatus(win32service.SERVICE_RUNNING)

    def SvcStop(self):
        self.ReportServiceStatus(win32service.SERVICE_STOP_PENDING)
        reactor.callFromThread(reactor.stop)

    def SvcDoRun(self):
        self.ReportServiceStatus(win32service.SERVICE_START_PENDING)
        try:

            reactor.callLater(1, self._notifyOfStart)

            from peek_agent_service import run_peek_agent_service

            run_peek_agent_service.main()

        except Exception as e:
            logger.exception(e)
            raise


# end patch


def main():
    win32serviceutil.HandleCommandLine(PeekSvc)


if __name__ == "__main__":
    main()
